package com.jz.agent.client.service;

import com.google.gson.Gson;
import com.jz.agent.client.DmpDsAgentClient;
import com.jz.agent.utils.DbInfoUtil;
import com.jz.dmp.agent.DmpAgentResult;
import com.jz.dmp.agent.ResultCode;
import com.jz.dmp.modules.model.DmpAgentDatasourceInfo;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.util.List;
import java.util.Map;

public class DmpOracleAgentClientService implements DmpDsAgentClient {
	
	private Gson gson = new Gson();
	private static Logger logger = LoggerFactory.getLogger(DmpOracleAgentClientService.class);

	@SuppressWarnings("unused")
	public DmpAgentResult testConnect(DmpAgentDatasourceInfo ds) {
		Connection conn = null;
		try {
			Class.forName(ds.getDriverClassName());
			conn = DriverManager.getConnection(
					ds.getJdbcUrl(), 
					ds.getUserName(), 
					ds.getPassword()
			);
			conn.close();
			return new DmpAgentResult(ResultCode.SUCCESS, gson.toJson(true));
		} catch (Exception e) {
			e.printStackTrace();
			return new DmpAgentResult(ResultCode.EXCEPTION, "oracle连通性异常："+e.getMessage());
		}  finally {
			try {
				if(conn != null)
				conn.close();
			} catch (SQLException e) {
				e.printStackTrace();
			}
		}
	}
	
	public DmpAgentResult getTableNameList(DmpAgentDatasourceInfo ds) {
		List<String> list = DbInfoUtil.getTableNameList(ds.getDriverClassName(), ds.getJdbcUrl(), ds.getUserName(), ds.getPassword());
		return new DmpAgentResult(ResultCode.SUCCESS, gson.toJson(list));
	}

	@SuppressWarnings({ "rawtypes" })
	public DmpAgentResult getTableColumnList(DmpAgentDatasourceInfo ds, String tableName) {
		List list = DbInfoUtil.getTableInfo(ds.getDriverClassName(), ds.getJdbcUrl(), ds.getUserName(), ds.getPassword(), tableName);
		return new DmpAgentResult(ResultCode.SUCCESS, gson.toJson(list));
	}

	@SuppressWarnings("unchecked")
	public DmpAgentResult previewData(DmpAgentDatasourceInfo ds, String tableName) {
		Map<String, Object> map = DbInfoUtil.getTableLimitData(ds.getDriverClassName(), ds.getJdbcUrl(), ds.getUserName(), ds.getPassword(), tableName);
		return new DmpAgentResult(ResultCode.SUCCESS, gson.toJson(map));
	}
	
}
